#!/bin/bash -e
#
# cbs 卸载脚本

cd `dirname $0`

FILE_CBS_CRON="cbs"
MODULE="cbs"
AUTHOR="megaops"
PREFIX="/tmp/cbs"   #安装路径

FILE_INFO="info.txt" #包信息描述文件
FILE_SVC_CTL="service_ctl.sh" #服务启/停控制脚本
PACKAGE="data.tar.bz2" #程序包 data.tar.gz
DAEMON="cbs"
MAIN_EXE=$DAEMON
PREFIX_DIR="/cyfs/vood/cbs/"
PREFIX_DATA="/cyfs/vood/data"

LOG_SET_TIME=true

COLOR_DFT='\033[0m'
COLOR_BRT='\033[0;1m'
COLOR_RED='\033[0;31m'
COLOR_GREEN='\033[0;32m'
COLOR_YELLOW='\033[1;33m'
COLOR_BLUE='\033[1;34m'

UTIL_FILENAME=`basename $0 2> /dev/null` || UTIL_FILENAME="unistor"
UTIL_MODE=${UTIL_FILENAME}

KEEPLOG=true
LOG_FILE=/var/log/${UTIL_FILENAME}.log

if [ ! -f "$LOG_FILE" ]; then
    touch "$LOG_FILE"
fi

#  --------- Common Functions -------------

TRIM_HEAD_SPACE()
{
    # trim字符串头部的 white space
    echo $1 | sed -r s/"^[[:space:]]+"/""/
}


WRITE_LOG(){
    # Log writer, append '[YYYY-mm-dd HH:MM:SS]$1$2$3,...' to  ${LOG_FILE}
    # $1,$2,... strings to be append
    if ${LOG_SET_TIME}; then
        echo "["$(date +"%Y-%m-%d %H:%M:%S")"][${UTIL_MODE}] "$@"" >> ${LOG_FILE}
    else
        echo "[${UTIL_MODE}]  "$@"" >> ${LOG_FILE}
    fi
}

# Format print and log record
PRINT(){
    #  Print to stdout and log file, started by '[$UTIL_MODE]'
    #  $1 $2 $3,... strings to be printed.
    echo -e "[${UTIL_MODE}]" "$@"
    if  ${KEEPLOG} ; then
        WRITE_LOG "$*"
    fi;
}

PERROR(){
    #  Print to stdout and log file with RED font, started by '[$UTIL_MODE]ERROR:'
    #  $1 $2 $3,... strings to be printed.
    echo -e "[${UTIL_MODE}]${COLOR_RED}" "ERROR:" "$@" "${COLOR_DFT}" 1>&2
    if ${KEEPLOG} ; then
        WRITE_LOG "ERROR: $*"
    fi;
}

PWARN(){
    #  Print to stdout and log file with YELLOW font, started by '[$UTIL_MODE]WARNING:'
    #  $1 $2 $3,... strings to be printed.
    echo -e "[${UTIL_MODE}]${COLOR_YELLOW}" "WARNING:" "$@" "${COLOR_DFT}"  1>&2
    if ${KEEPLOG} ; then
        WRITE_LOG "WARNING: $*"
    fi;
}

PSUCCESS(){
    # Print to stdout and log file with 'brighter' effect, started by '[$UTIL_MODE]'
    # $1 $2 $3,... strings to be printed.
    echo -e "[${UTIL_MODE}]${COLOR_BRT}" "$@" "${COLOR_DFT}"
    if ${KEEPLOG} ; then
        WRITE_LOG "$*"
    fi;
}

PINFO(){
    # Print to stdout and log file with 'brighter' effect, started by '[$UTIL_MODE]'
    # $1 $2 $3,... strings to be printed.
    echo -e "[${UTIL_MODE}]${COLOR_BRT}" "$@" "${COLOR_DFT}"
    if ${KEEPLOG} ; then
        WRITE_LOG "$*"
    fi;
}


PBLUE(){
    # Print to stdout and log file with BLUE font, started by '[$UTIL_MODE]'
    # $1 $2 $3,... strings to be printed.
    echo -e "[${UTIL_MODE}]${COLOR_BLUE}" "$@" "${COLOR_DFT}"
    if ${KEEPLOG} ; then
        WRITE_LOG "$*"
    fi;
}



GET_CONF_ITEM()
{
    # linux config item get
    # $1 filename
    # $2 key
    # return value
    local file="$1"
    local key="$2"
    if [ ! -f "${file}" ]; then
        PERROR "<$FUNCNAME> file '$file' not exist"
        return 1
    fi
    local value=$(cat ${file} |grep -P "^${key}[ ]*=" |awk -F "[=]" '{print $2}'|tail -n 1)
    echo $(TRIM_HEAD_SPACE "${value}")
    # modified by n16111 2018-11-14 17:48:47： support "key = value" (allow spaces around '=')
    # modified by n16111 2019-8-6 15:56:44： return last key's value if multi keys with same name exist
}


# get version
VERSION="$(GET_CONF_ITEM ${FILE_INFO} 'version')"

# -- Basic Info --
echo ""
PRINT "-----------------------------------"
PBLUE "module: ${MODULE}"
PRINT "version:${VERSION}"
PRINT "author:${AUTHOR}"
PRINT "package:${PACKAGE}"
PRINT "install prefix:${PREFIX}"
PRINT "-----------------------------------"

# -- Service/Process stop --
PINFO "stopping service ${MODULE}..."
set -x
systemctl daemon-reload
service ${MODULE} stop || killall -9 $DAEMON
set +x


rm -rf ${PREFIX}
rm -rf ${PREFIX_DIR}
rm -rf ${PREFIX_DATA}
rm -rf /lib/systemd/system/cbs.service
rm -rf /usr/bin/check-cbs.sh
rm -f /etc/cron.d/${FILE_CBS_CRON}

PRINT "delete ${PREFIX}"
PRINT "delete ${PREFIX_DIR}"
PRINT "delete ${PREFIX_DATA}"
PRINT "delete /lib/systemd/system/cbs.service"
PRINT "delete /usr/bin/check-cbs.sh"
PRINT "delete /etc/cron.d/${FILE_CBS_CRON}"

# -- Complete --
PINFO "'${MODULE}' uninstall complete."
